@@ -28,28 +28,24 @@ def insert(db: Connection, table: str, keys: List[str], values: List[Union[int,
     )
 
 
-def select(db: Connection, table: str, fields: List[str], key: str, key_value: Union[int, str], like: bool = False
+def select(db: Connection, table: str, fields: List[str], keys: List[str], key_values: List[Union[int, str]],
+           like: bool = False, and_: bool = True, order: List[str] = None
            ) -> Cursor:
-    return db.execute(
-        f'''SELECT {",".join(fields)} FROM {table} WHERE {key} {"like" if like else "="} ?''',
-        (key_value,)
-    )
-
-
-def select_multi(db: Connection, table: str, fields: List[str], keys: List[str], key_values: List[Union[int, str]],
-                 like: bool = False, and_: bool = True
-                 ) -> Cursor:
     op: str = "like" if like else "="
     logic: str = "AND" if and_ else "OR"
-    where: List[str] = [f"{key} {op} ?" for key in keys for _ in key_values]
+    where: List[str] = [f"{key} {op} ?" for key in keys]
+    order = [] if order is None else order
     return db.execute(
-        f'''SELECT {",".join(fields)} FROM {table} WHERE {f" {logic} ".join(where)}''',
-        key_values * len(keys)
+        f'''SELECT {",".join(fields)} FROM {table}
+        WHERE {f" {logic} ".join(where)}
+        {"ORDER BY " + ','.join(order) if order else ""}''',
+        key_values
     )
 
 
-def select_all(db: Connection, table: str, fields: List[str]) -> Cursor:
-    return db.execute(f'''SELECT {",".join(fields)} FROM {table}''')
+def select_all(db: Connection, table: str, fields: List[str], order: List[str] = None) -> Cursor:
+    order = [] if order is None else order
+    return db.execute(f'''SELECT {",".join(fields)} FROM {table} {"ORDER BY " + ','.join(order) if order else ""}''')
 
 
 def update(db: Connection, table: str, fields: List[str], values: List[Union[int, str]], key: str, key_value: str):
